<?php
namespace Ep\Hak\Service;

use Ep\Hak\HakService;
use Ep\WordPress\Service\AbstractWordPressService;
use WC_Coupon;

/**
 * Class CouponService
 *
 * @package Ep\Hak
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class CouponService extends AbstractWordPressService
{
	public function attach(): void
	{
		add_filter('woocommerce_get_shop_coupon_data', [$this, 'getCouponData'], 10, 2);
		add_filter('woocommerce_coupon_is_valid', [$this, 'isCouponValid'], 10, 2);
		add_filter('woocommerce_coupon_message', [$this, 'getCouponMessage'], 10, 3);
		add_filter('woocommerce_cart_totals_coupon_label', [$this, 'getCouponLabel'], 10, 2);
		add_filter('woocommerce_cart_totals_coupon_html', [$this, 'getCouponHtml'], 10, 2);
	}

	/**
	 * @param $false
	 * @param $data
	 *
	 * @return mixed
	 */
	public function getCouponData($false, $data)
	{
		$config = $this->getConfig('hak');

		if (HakService::COUPON_CODE === $data) {
			return [
				'name' => HakService::COUPON_CODE,
				'discount_type' => 'percent',
				'amount' => intval($config['discountPercentage']),
			];
		}

		return $false;
	}

	/**
	 * @param $label
	 * @param WC_Coupon $coupon
	 *
	 * @return string
	 */
	public function getCouponLabel($label, WC_Coupon $coupon)
	{
		$config = $this->getConfig('hak');

		if (HakService::COUPON_CODE === $coupon->get_code('')) {
			return esc_html($config['couponName']);
		}

		return $label;
	}

	/**
	 * @param $html
	 * @param WC_Coupon $coupon
	 *
	 * @return mixed
	 */
	public function getCouponHtml($html, WC_Coupon $coupon)
	{
		if (HakService::COUPON_CODE === $coupon->get_code('')) {
			return preg_replace('#<a[^<]+</a>$#', '', $html);
		}

		return $html;
	}

	/**
	 * @param $message
	 * @param $messageCode
	 * @param WC_Coupon $coupon
	 *
	 * @return string
	 */
	public function getCouponMessage($message, $messageCode, WC_Coupon $coupon)
	{
		if (HakService::COUPON_CODE === $coupon->get_code('')) {
			switch ($messageCode) {
				case WC_Coupon::WC_COUPON_SUCCESS:
					return 'HAK popust uspješno primjenjen.';
				case WC_Coupon::WC_COUPON_REMOVED:
					return 'HAK popust uklonjen.';
			}
		}

		return $message;
	}

	/**
	 * Za HAK kupon provjerava da li je korisnik član HAK-a.
	 *
	 * @param $valid
	 * @param WC_Coupon $coupon
	 *
	 * @return bool
	 */
	public function isCouponValid($valid, WC_Coupon $coupon)
	{
		if (HakService::COUPON_CODE === $coupon->get_code('')) {
			/** @var HakService $hak */
			$hak = $this->services->get('Hak');
			return $hak->validate();
		}

		return $valid;
	}
}